
```
pip install jupyter_contrib_nbextensions
jupyter contrib nbextension install --user  # or --sys-prefix ??
jupyter nbextension enable
```

Issue with toc:
See https://github.com/ipython-contrib/jupyter_contrib_nbextensions/issues/1533
(jinja2.exceptions.TemplateNotFound: toc2)
